.. s1etad documentation master file, created by
   sphinx-quickstart on Mon Aug 31 13:12:31 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

====================
s1etad documentation
====================

:version: |release|
:date: |today|


.. toctree::
   :maxdepth: 2

   quickstart
   notebooks/s1etad-tutorial
   notebooks/use-case-01_burst_selection
   notebooks/use-case-02_corrections
   notebooks/use-case-03_footprints
   notebooks/use-case-04_corner_reflector
   notebooks/S1-ETAD-Product_Quick_User_Guide
   examples
   api/modules
   TODO
   news


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
